
/**************************************************************************
 September 9th, 2013
 VERSION 1
 
 THIS IS AN EXAMPLE OF A STATA DO PROGRAM THAT LINKS NHIS DATA FROM 2004 
 FORWARD TO AN IHIS DATA EXTRACT IN STATA FILE
 FORMAT.

 NOTES:

 EVERYWHERE IN THIS .DO FILE WHERE 'YEAR' IS WRITTEN YOU MUST FIND AND REPLACE
 'YEAR' WITH THE YEAR OF DATA YOU ARE MERGING.
 
 EXECUTING THIS PROGRAM WILL REPLACE IHISLINKHYEAR.LOG IF THE FILE
 ALREADY EXISTS IN THE SPECIFIED DIRECTORY.
 
 CERTAIN VARIABLES FOR LINKING, INCLUDING SRVY_YR HHX NON_INTV, IN NHIS  
 DATA SHOULD NOT BE CHANGED OR RENAMED BEFORE THE MERGE. 
 
 THIS DO FILE WILL WORK FOR LINKING HOUSEHOLD LEVEL DATA. 

    STEP 1: CHANGE DATA PATH AND FILE NAMES IN SECTION 1 AS NEEDED.
	    SECTION 1.1: SPECIFY THE DIRECTORY PATH OF THE LOG FILE. 
	    SECTION 1.2: SPECIFY THE DIRECTORY PATH AND NAME OF NHIS DATA.
	    	    	(MERGING DATA).
	    SECTION 1.3: SPECIFY THE DIRECTORY PATH AND NAME OF IHIS DATA
	    	    	(MASTER DATA).
	    SECTION 1.4: SPECIFY THE DIRECTORY PATH OF FINAL MERGED DATA. 
	    
	    REMOVE < and > INSIDE QUOTES.

    STEP 2: SPECIFY THE VARIABLES OF THE NHIS DATA TO BE KEPT IN SECTION 2.
    
	    REMOVE < and > INSIDE QUOTES.

    STEP 3: SAVE AND RUN DO FILE.
    
***************************************************************************/


clear

set more off


/************************************************************************/
/*** SECTION 1: DATA PATH AND FILE NAMES; CHANGE FILE NAMES AS NEEDED ***/
/************************************************************************/

 * SECTION 1.1: SPECIFY THE DIRECTORY PATH WHERE YOU WANT TO STORE THE LOG FILE  *
 *    Replace <replace with your directory path> with the name of the directory  *
 *    where you want to store your log. Remove < and > .  			 *

 global linkloghYEAR "<replace with your directory path>\ihislinkhYEAR.log"

 * SECTION 1.2: SPECIFY THE DIRECTORY PATH AND NAME OF NHIS DATA (MERGING DATA). *
 *    Replace <replace with your directory path and name of dataset> with the    *
 *    name of your NHIS file. Remove < and > .  				 *

 global nhishYEAR    "<replace with your directory path and name of dataset>"            

 * SECTION 1.3: SPECIFY THE DIRECTORY PATH AND NAME OF IHIS DATA (MASTER DATA)   *
 *    Replace <replace with your directory path and name of dataset> with the    *
 *    name of your IHIS file. Remove < and > .  				 *

 global ihishYEAR    "<replace with your directory path and name of dataset>"
 
 * SECTION 1.4: SPECIFY THE DIRECTORY PATH WHERE YOU WANT TO STORE FINAL MERGED DATA *
 *    Replace <replace with your directory path> with the name of the directory  *
 *    where you want to store your final merged data file. Remove < and > . 	 *

 global linkedhYEAR  "<replace with your directory path>\linkeddatahYEAR.dta"    



/**************************************************************************************/
/*** SECTION 2: SPECIFY THE VARIABLES OF THE NHIS DATA TO BE KEPT INSIDE QUOTES " " ***/
/**************************************************************************************/

 * Replace <insert names of NHIS variables you would like to merge here> with the *
 * names of the NHIS variables you want to merge to IHIS. Separate the variables  * 
 * in your list with a space or use a varlist. Remove < and > .			  *	
 
 global keepvarshYEAR "<insert names of NHIS variables you would like to merge here>"


    
/***************************************************************************/
/***************************************************************************/
/***************************************************************************/

capture log close

log using `"$linkloghYEAR"', replace


/************************************************************/
/*** SECTION 3: PREPARE NHIS DATA TO MERGE WITH IHIS DATA ***/
/************************************************************/

 use `"$nhishYEAR"', clear  /* open NHIS data */



* SECTION 3.1: CHECK DUPLICATES FOR UNIQUE IDENTIFIER IN NHIS DATA *
 duplicates report hhx



* SECTION 3.2: GENERATE LINKING KEY *
 gen int year=srvy_yr

 gen str preyear="0000" 

 egen nhishid=concat(preyear year hhx)



* SECTION 3.3: CHECK DUPLICATES OF LINKING KEY IN NHIS DATA *
 duplicates report nhishid

 drop preyear



* SECTION 3.4: KEEP VARIABLES FROM NHIS DATA * 
 gen completed = (non_intv==.)
 
 replace completed=2 if completed==0

 keep year nhishid completed $keepvarshYEAR  /* keep year nhishid completed and relevant variables */



* SECTION 3.5: SAVE USING NHIS DATA AS A TEMPORARY FILE FOR THE MERGE *
 tempfile tfile    

 sort year nhishid

 save `"tfile"'  /* saved NHIS file as a temporary file for the merge */
	


/*************************************************/
/*** SECTION 4: MERGE NHIS DATA WITH IHIS DATA ***/
/*************************************************/

 use `"$ihishYEAR"', clear  /* open IHIS data */



* SECTION 4.1: CHECK DUPLICATES OF LINKING KEY IN IHIS DATA *
 duplicates report nhishid

 sort year nhishid

 merge year nhishid using `"tfile"'

 bysort year: tab _merge completed, m

 drop _merge completed

 save `"$linkedhYEAR"', replace  /* final merged data */

 capture log close



